@@ -2,9 +2,19 @@
 Creates config file from logsheet. Will move into either utils or example folder.
 """
 
+import numpy as np
 import pandas as pd
 
 
+class LogsheetError(ValueError):
+    """
+    For incorrect values within a logsheet that
+    can break `create_config` with opaque error messages.
+    """
+
+    pass
+
+
 def create_config(log, config_file, tab=None):
     """
     Create config csv file out of tab in logsheet.
@@ -32,6 +42,10 @@ def create_config(log, config_file, tab=None):
                 "Filter": str,
             },
         )
+    else:
+        raise NotImplementedError(
+            "Specified log file is of an " "unsupported file type."
+        )
     logdf = logdf[pd.notna(logdf["Start"])]
     savedf = logdf[["Object", "ExpTime", "Filter", "Comments"]]
 
@@ -41,6 +55,10 @@ def create_config(log, config_file, tab=None):
     for row in range(0, nrows):
         start = logdf["Start"].iloc[row]
         end = logdf["End"].iloc[row]
+        if np.isnan(start) or np.isnan(end):
+            raise LogsheetError(
+                f"Check for empty start or end entry in row {row}."
+            )
         filelist = range(start, end + 1)
         filenums.append(filelist)
 
